==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/de_DE.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-App",
    "Show something" : "Etwas anzeigen",
    "Customize" : "Anpassen",
    "Edit widgets" : "Widgets bearbeiten",
    "Get more widgets from the app store" : "Holen Sie sich weitere Widgets aus dem App Store",
    "Change background image" : "Hintergrundbild ändern",
    "Weather service" : "Wetterdienst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zu Ihrem Datenschutz werden die Wetterdaten von Ihrem Nextcloud-Server für Sie angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält.",
    "Weather data from Met.no" : "Wetterdaten von Met.no",
    "geocoding with Nominatim" : "Geokodierung mit Nominatim",
    "elevation data from OpenTopoData" : "Höhendaten von OpenTopoData",
    "Weather" : "Wetter",
    "Status" : "Status",
    "Good evening, {name}" : "Guten Abend {name}",
    "Good evening" : "Guten Abend",
    "Good afternoon, {name}" : "Guten Tag {name}",
    "Good afternoon" : "Guten Tag",
    "Good morning, {name}" : "Guten Morgen {name}",
    "Good morning" : "Guten Morgen",
    "Good night, {name}" : "Gute Nacht {name}",
    "Good night" : "Gute Nacht",
    "Pick from files" : "Aus Dateien wählen",
    "Default images" : "Standardbilder",
    "Plain background" : "Einfacher Hintergrund",
    "Insert from {productName}" : "Von {productName} einfügen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/de_DE.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard-App",
    "Show something" : "Etwas anzeigen",
    "Customize" : "Anpassen",
    "Edit widgets" : "Widgets bearbeiten",
    "Get more widgets from the app store" : "Holen Sie sich weitere Widgets aus dem App Store",
    "Change background image" : "Hintergrundbild ändern",
    "Weather service" : "Wetterdienst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zu Ihrem Datenschutz werden die Wetterdaten von Ihrem Nextcloud-Server für Sie angefordert, so dass der Wetterdienst keine persönlichen Informationen erhält.",
    "Weather data from Met.no" : "Wetterdaten von Met.no",
    "geocoding with Nominatim" : "Geokodierung mit Nominatim",
    "elevation data from OpenTopoData" : "Höhendaten von OpenTopoData",
    "Weather" : "Wetter",
    "Status" : "Status",
    "Good morning" : "Guten Morgen",
    "Good morning, {name}" : "Guten Morgen {name}",
    "Good afternoon" : "Guten Tag",
    "Good afternoon, {name}" : "Guten Tag {name}",
    "Good evening" : "Guten Abend",
    "Good evening, {name}" : "Guten Abend {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Pick from Files" : "Aus Dateien auswählen",
    "Default images" : "Standardbilder",
    "Plain background" : "Einfacher Hintergrund",
    "Insert from {productName}" : "Von {productName} einfügen",
    "Good night, {name}" : "Gute Nacht {name}",
    "Good night" : "Gute Nacht",
    "Pick from files" : "Aus Dateien wählen"
},
"nplurals=2; plural=(n != 1);");
